@@ -24,6 +24,8 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/go-cmp/cmp"
+
 	autoscalingv1 "k8s.io/api/autoscaling/v1"
 	apiequality "k8s.io/apimachinery/pkg/api/equality"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -32,8 +34,7 @@ import (
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
-	"k8s.io/apimachinery/pkg/util/diff"
-	"k8s.io/apiserver/pkg/endpoints/handlers/fieldmanager"
+	"k8s.io/apimachinery/pkg/util/managedfields"
 	genericapirequest "k8s.io/apiserver/pkg/endpoints/request"
 	"k8s.io/apiserver/pkg/registry/generic"
 	registrytest "k8s.io/apiserver/pkg/registry/generic/testing"
@@ -91,7 +92,8 @@ func newStorage(t *testing.T) (customresource.CustomResourceStorage, *etcd3testi
 	}
 	table, _ := tableconvertor.New(headers)
 
-	storage := customresource.NewStorage(
+	storage, err := customresource.NewStorage(
+		groupResource,
 		groupResource,
 		kind,
 		schema.GroupVersionKind{Group: "mygroup.example.com", Version: "v1beta1", Kind: "NoxuItemList"},
@@ -104,12 +106,16 @@ func newStorage(t *testing.T) (customresource.CustomResourceStorage, *etcd3testi
 			nil,
 			status,
 			scale,
+			nil,
 		),
 		restOptions,
 		[]string{"all"},
 		table,
-		fieldmanager.ResourcePathMappings{},
+		managedfields.ResourcePathMappings{},
 	)
+	if err != nil {
+		t.Errorf("unexpected error: %v", err)
+	}
 
 	return storage, server
 }
@@ -408,7 +414,7 @@ func TestScaleGet(t *testing.T) {
 
 	got := obj.(*autoscalingv1.Scale)
 	if !apiequality.Semantic.DeepEqual(got, want) {
-		t.Errorf("unexpected scale: %s", diff.ObjectDiff(got, want))
+		t.Errorf("unexpected scale: %s", cmp.Diff(got, want))
 	}
 }
 
